'From Squeak2.9alpha of 25 July 2000 [latest update: #2618] on 18 September 2000 at 3:49:47 pm'!
"Change Set:		streamWrapper
Date:			18 September 2000
Author:			Michael Rueger

StreamWrapper is an abstract class. Concrete subclasses can either be 
- wrappers for objects like sockets
- reader/writer classes relying on the stream protocol in StreamWrapper for streaming over a stream. This stream can then either be an internal or external one."!

Stream subclass: #StreamWrapper
	instanceVariableNames: 'stream '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Collections-Streams'!

!StreamWrapper commentStamp: '<historical>' prior: 0!
I am an abstract class that represents stream streaming over the contents of another stream.
This way my subclasses can be used to stream over different sorts of streams like internal, file or network streams without the need to know what they are dealing with.
!

StreamWrapper class
	instanceVariableNames: ''!

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:07'!
contents
	"Answer with a copy of my collection from 1 to readLimit."

	^self stream contents! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:13'!
flush
	self stream flush! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:07'!
next
	^self stream next! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:07'!
next: anInteger 
	^self stream next: anInteger! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:24'!
next: n into: aCollection
	"Read n objects into the given collection.
	Return aCollection or a partial copy if less than
	n elements have been read."
	^self next: n into: aCollection startingAt: 1! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:47'!
next: n into: aCollection startingAt: startIndex
	"Read n objects into the given collection. 
	Return aCollection or a partial copy if less than
	n elements have been read."
	^self stream next: n into: aCollection startingAt: startIndex! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:25'!
next: anInteger putAll: aCollection
	"Store the next anInteger elements from the given collection."
	^self next: anInteger putAll: aCollection startingAt: 1! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:47'!
next: anInteger putAll: aCollection startingAt: startIndex
	"Store the next anInteger elements from the given collection."
	self stream next: anInteger putAll: aCollection startingAt: startIndex! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:26'!
nextDelimited: terminator
	^self stream nextDelimited: terminator! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:48'!
nextInto: buffer 
	"fill buffer from my collection"
	^self stream nextInto: buffer! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:30'!
nextLine
	"Answer next line (may be empty), or nil if at end"

	^self stream nextLine! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:39'!
nextPut: anObject 
	"Insert the argument, anObject, as the next object accessible by the 
	receiver. Answer anObject."

	^self stream nextPut: anObject! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:39'!
nextPutAll: aCollection 
	"Append the elements of aCollection to the sequence of objects accessible 
	by the receiver. Answer aCollection."

	^self stream nextPutAll: aCollection! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:37'!
peek
	"Answer what would be returned if the message next were sent to the 
	receiver. If the receiver is at the end, answer nil."

	^self stream peek! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:37'!
peekFor: anObject 
	"Answer false and do not move over the next element if it is not equal to 
	the argument, anObject, or if the receiver is at the end. Answer true 
	and increment the position for accessing elements, if the next element is 
	equal to anObject."

	^self stream peekFor: anObject! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 9/28/1999 17:20'!
size
	^self stream size! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:40'!
upTo: anObject 
	"Answer a subcollection from the current access position to the 
	occurrence (if any, but not inclusive) of anObject in the receiver. If 
	anObject is not in the collection, answer the entire rest of the receiver."
	^self stream upTo: anObject! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:44'!
upToAll: aCollection
	"Answer a subcollection from the current access position to the occurrence (if any, but not inclusive) of aCollection. If aCollection is not in the stream, answer the entire rest of the stream."

	^self stream upToAll: aCollection! !

!StreamWrapper methodsFor: 'accessing' stamp: 'mir 8/4/2000 16:40'!
upToEnd
	"answer the remaining elements in the stream"
	^self stream upToEnd! !

!StreamWrapper methodsFor: 'private' stamp: 'mir 9/28/1999 17:19'!
stream
	^stream! !

!StreamWrapper methodsFor: 'private' stamp: 'mir 8/4/2000 16:48'!
streamOver: anotherStream
	stream _ anotherStream! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 8/4/2000 16:43'!
match: subCollection
	"Set the access position of the receiver to be past the next occurrence of the subCollection. Answer whether subCollection is found.  No wildcards, and case does matter."

	^self stream match: subCollection! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 8/4/2000 16:45'!
position
	"Answer the current position of accessing the sequence of objects."
	^self stream position! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 8/4/2000 16:45'!
position: newPosition
	"Set the current position for accessing the objects to be anInteger, as long 
	as anInteger is within the bounds of the receiver's contents. If it is not, 
	create an error notification."
	^self stream position: newPosition! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 8/4/2000 16:45'!
reset
	"Set the receiver's position to the beginning of the sequence of objects."
	^self stream reset! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 8/4/2000 16:45'!
setToEnd
	"Set the position of the receiver to the end of the sequence of objects."

	self stream setToEnd! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 10/6/1999 17:29'!
skip: offset
	^self stream skip: offset! !

!StreamWrapper methodsFor: 'positioning' stamp: 'mir 8/4/2000 16:46'!
skipTo: anObject 
	"Set the access position of the receiver to be past the next occurrence of 
	anObject. Answer whether anObject is found."

	self stream skipTo: anObject! !

!StreamWrapper methodsFor: 'testing' stamp: 'mir 10/4/1999 18:55'!
atEnd
	^self stream atEnd! !

!StreamWrapper methodsFor: 'testing' stamp: 'mir 8/4/2000 16:42'!
closed
	^self stream closed! !

!StreamWrapper methodsFor: 'testing' stamp: 'mir 8/4/2000 16:12'!
isBinary
	^self stream isBinary! !

!StreamWrapper methodsFor: 'testing' stamp: 'mir 8/4/2000 16:41'!
isStream
	"Return true if the receiver responds to the stream protocol"
	^true! !


!StreamWrapper class methodsFor: 'instance creation' stamp: 'mir 8/4/2000 15:45'!
on: anotherStream
	^self basicNew streamOver: anotherStream! !

!StreamWrapper class methodsFor: 'instance creation' stamp: 'mir 9/28/1999 17:19'!
streamOver: anotherStream
	^self basicNew streamOver: anotherStream! !

